Test Pause And Resume
in normal case the AUT test should fail
setTimeout | 120000 |
open | ../core/TestRunner.html?test=../tests/dogfood/aut/PauseTestSuite.html |
waitForEval | window.htmlTestRunner.testCaseLoaded | true
click | runSuite |
waitForText | testFailures | 1
verifyAttribute | pauseTitle@class | regex:status_failed
click pause to make the test pass
open | ../core/TestRunner.html?test=../tests/dogfood/aut/PauseTestSuite.html |
waitForEval | window.htmlTestRunner.testCaseLoaded | true
click | runSuite |
waitForText | content | Loading text...
click | pauseTest |
waitForText | content | This is final text
click | pauseTest |
waitForText | commandPasses | 2
verifyAttribute | pauseTitle@class | regex:status_passed